@@ -111,13 +111,13 @@ class SoftwareProperties(object):
     """Backup all apt configuration options"""
     self.apt_conf_backup = {}
     for option in softwareproperties.CONF_MAP.keys():
-        value = apt_pkg.Config.FindI(softwareproperties.CONF_MAP[option])
+        value = apt_pkg.config.find_i(softwareproperties.CONF_MAP[option])
         self.apt_conf_backup[option] = value
 
   def restore_apt_conf(self):
     """Restore the stored apt configuration"""
     for option in self.apt_conf_backup.keys():
-        apt_pkg.Config.Set(softwareproperties.CONF_MAP[option],
+        apt_pkg.config.set(softwareproperties.CONF_MAP[option],
                            str(self.apt_conf_backup[option]))
     self.write_config()
 
@@ -125,21 +125,21 @@ class SoftwareProperties(object):
     """ Parse the apt cron configuration. Try to fit a predefined use case 
         and return it. Special case: if the user made a custom 
         configurtation, that we cannot represent it will return None """
-    if apt_pkg.Config.FindI(softwareproperties.CONF_MAP["autoupdate"]) > 0:
+    if apt_pkg.config.find_i(softwareproperties.CONF_MAP["autoupdate"]) > 0:
         # Autodownload
-        if apt_pkg.Config.FindI(softwareproperties.CONF_MAP["unattended"]) == 1\
-           and apt_pkg.Config.FindI(softwareproperties.CONF_MAP["autodownload"]) == 1 :
+        if apt_pkg.config.find_i(softwareproperties.CONF_MAP["unattended"]) == 1\
+           and apt_pkg.config.find_i(softwareproperties.CONF_MAP["autodownload"]) == 1 :
             return softwareproperties.UPDATE_INST_SEC
-        elif apt_pkg.Config.FindI(softwareproperties.CONF_MAP["autodownload"]) == 1 and  \
-             apt_pkg.Config.FindI(softwareproperties.CONF_MAP["unattended"]) == 0:
+        elif apt_pkg.config.find_i(softwareproperties.CONF_MAP["autodownload"]) == 1 and  \
+             apt_pkg.config.find_i(softwareproperties.CONF_MAP["unattended"]) == 0:
             return softwareproperties.UPDATE_DOWNLOAD
-        elif apt_pkg.Config.FindI(softwareproperties.CONF_MAP["unattended"]) == 0 and \
-             apt_pkg.Config.FindI(softwareproperties.CONF_MAP["autodownload"]) == 0:
+        elif apt_pkg.config.find_i(softwareproperties.CONF_MAP["unattended"]) == 0 and \
+             apt_pkg.config.find_i(softwareproperties.CONF_MAP["autodownload"]) == 0:
             return softwareproperties.UPDATE_NOTIFY
         else:
             return None
-    elif apt_pkg.Config.FindI(softwareproperties.CONF_MAP["unattended"]) == 0 and \
-         apt_pkg.Config.FindI(softwareproperties.CONF_MAP["autodownload"]) == 0:
+    elif apt_pkg.config.find_i(softwareproperties.CONF_MAP["unattended"]) == 0 and \
+         apt_pkg.config.find_i(softwareproperties.CONF_MAP["autodownload"]) == 0:
         return softwareproperties.UPDATE_MANUAL
     else:
         return None
@@ -150,30 +150,30 @@ class SoftwareProperties(object):
         actual upgrading function, the upgrade function, e.g. unattended, 
         will run every day, if enabled. """
     if state == softwareproperties.UPDATE_INST_SEC:
-        apt_pkg.Config.Set(softwareproperties.CONF_MAP["unattended"], str(1))
-        apt_pkg.Config.Set(softwareproperties.CONF_MAP["autodownload"], str(1))
+        apt_pkg.config.set(softwareproperties.CONF_MAP["unattended"], str(1))
+        apt_pkg.config.set(softwareproperties.CONF_MAP["autodownload"], str(1))
     elif state == softwareproperties.UPDATE_DOWNLOAD:
-        apt_pkg.Config.Set(softwareproperties.CONF_MAP["autodownload"], str(1))
-        apt_pkg.Config.Set(softwareproperties.CONF_MAP["unattended"], str(0))
+        apt_pkg.config.set(softwareproperties.CONF_MAP["autodownload"], str(1))
+        apt_pkg.config.set(softwareproperties.CONF_MAP["unattended"], str(0))
     elif state == softwareproperties.UPDATE_NOTIFY:
-        apt_pkg.Config.Set(softwareproperties.CONF_MAP["autodownload"], str(0))
-        apt_pkg.Config.Set(softwareproperties.CONF_MAP["unattended"], str(0))
+        apt_pkg.config.set(softwareproperties.CONF_MAP["autodownload"], str(0))
+        apt_pkg.config.set(softwareproperties.CONF_MAP["unattended"], str(0))
     else:
-        apt_pkg.Config.Set(softwareproperties.CONF_MAP["autoupdate"], str(0))
-        apt_pkg.Config.Set(softwareproperties.CONF_MAP["unattended"], str(0))
-        apt_pkg.Config.Set(softwareproperties.CONF_MAP["autodownload"], str(0))
+        apt_pkg.config.set(softwareproperties.CONF_MAP["autoupdate"], str(0))
+        apt_pkg.config.set(softwareproperties.CONF_MAP["unattended"], str(0))
+        apt_pkg.config.set(softwareproperties.CONF_MAP["autodownload"], str(0))
     self.set_modified_config()
 
   def set_update_interval(self, days):
       """Set the interval in which we check for available updates"""
       # Only write the key if it has changed
-      if not days == apt_pkg.Config.FindI(softwareproperties.CONF_MAP["autoupdate"]):
-          apt_pkg.Config.Set(softwareproperties.CONF_MAP["autoupdate"], str(days))
+      if not days == apt_pkg.config.find_i(softwareproperties.CONF_MAP["autoupdate"]):
+          apt_pkg.config.set(softwareproperties.CONF_MAP["autoupdate"], str(days))
           self.set_modified_config()
 
   def get_update_interval(self):
     """ Returns the interval of the apt periodic cron job """
-    return apt_pkg.Config.FindI(softwareproperties.CONF_MAP["autoupdate"])
+    return apt_pkg.config.find_i(softwareproperties.CONF_MAP["autoupdate"])
 
   def get_release_upgrades_policy(self):
     """
@@ -433,11 +433,13 @@ class SoftwareProperties(object):
     """Render a nice output to show the source in a treeview"""
     if source.template == None:
         if source.comment:
-            contents = "<b>%s</b>" % escape(source.comment)
+            contents = "<b>%s</b> (%s %s" % (escape(source.comment),
+                                              source.uri, source.dist)
             # Only show the components if there are more than one
             if len(source.comps) > 1:
                 for c in source.comps:
                     contents += " %s" % c
+            contents += ")"
         else:
             contents = "<b>%s %s</b>" % (source.uri, source.dist)
             for c in source.comps:
@@ -564,20 +566,20 @@ class SoftwareProperties(object):
       content = []
       if os.path.isfile(periodic):
         content = open(periodic, "r").readlines()
-        cnf = apt_pkg.Config.SubTree("APT::Periodic")
+        cnf = apt_pkg.config.subtree("APT::Periodic")
 
         # then write a new file without the updated keys
         f = open(periodic, "w")
         for line in content:
-          for key in cnf.List():
+          for key in cnf.list():
             if line.find("APT::Periodic::%s" % (key)) >= 0:
               break
           else:
             f.write(line)
 
         # and append the updated keys
-        for i in cnf.List():
-          f.write("APT::Periodic::%s \"%s\";\n" % (i, cnf.FindI(i)))
+        for i in cnf.list():
+          f.write("APT::Periodic::%s \"%s\";\n" % (i, cnf.find_i(i)))
         f.close()    
 
   def save_sourceslist(self):
@@ -625,12 +627,15 @@ class SoftwareProperties(object):
     Add a source with the given apt line and auto-add
     signing key if we have it in the whitelist
     """
-    (line, file) = expand_ppa_line(line.strip(), self.distro.codename)
-    self.check_and_add_key_for_whitelisted_channels(line)
-    new_entry = SourceEntry(line, file)
-    if new_entry.invalid:
+    (deb_line, file) = expand_ppa_line(line.strip(), self.distro.codename)
+    debsrc_line = 'deb-src' + deb_line[3:]
+    new_deb_entry = SourceEntry(deb_line, file)
+    new_debsrc_entry = SourceEntry(debsrc_line, file)
+    if new_deb_entry.invalid or new_debsrc_entry.invalid:
       return False
-    self.sourceslist.list.append(new_entry)
+    self.check_and_add_key_for_whitelisted_channels(deb_line)
+    self.sourceslist.list.append(new_deb_entry)
+    self.sourceslist.list.append(new_debsrc_entry)
     self.set_modified_sourceslist()
     return True
 
@@ -640,13 +645,15 @@ class SoftwareProperties(object):
     # (the line that we just remove), then all references to that
     # file are gone and the file is not saved. we work around that
     # here
-    if source.file != apt_pkg.Config.FindFile("Dir::Etc::sourcelist"):
+    if source.file != apt_pkg.config.find_file("Dir::Etc::sourcelist"):
       self.sourceslist.list.append(SourceEntry("", file=source.file))
     self.sourceslist.remove(source)
     self.set_modified_sourceslist()
 
   def add_key(self, path):
     """Add a gnupg key to the list of trusted software vendors"""
+    if not isinstance(path, unicode):
+      path = unicode(path) # allows non-ascii filenames
     if not os.path.exists(path):
         return False
     try:
