@@ -31,10 +31,9 @@ import re
 from xml.sax.saxutils import escape
 
 import gtk
-import gtk.glade
 import gobject
 
-from SimpleGladeApp import SimpleGladeApp
+from SimpleGtkbuilderApp import SimpleGtkbuilderApp
 from aptsources.sourceslist import SourceEntry
 from DialogAdd import DialogAdd
 from DialogMirror import DialogMirror
@@ -79,7 +78,7 @@ def error(parent_window, summary, msg):
   dialog.destroy()
   return False
 
-class SoftwarePropertiesGtk(SoftwareProperties,SimpleGladeApp):
+class SoftwarePropertiesGtk(SoftwareProperties,SimpleGtkbuilderApp):
   def __init__(self, datadir=None, options=None, file=None, parent=None):
     """ Provide a GTK based graphical user interface to configure
         the used software repositories, corresponding authentication keys
@@ -87,8 +86,8 @@ class SoftwarePropertiesGtk(SoftwareProperties,SimpleGladeApp):
     SoftwareProperties.__init__(self, options=options, datadir=datadir)
     gtk.window_set_default_icon_name("software-properties")
 
-    SimpleGladeApp.__init__(self, datadir+"glade/main.glade",
-                            None, domain="software-properties")
+    SimpleGtkbuilderApp.__init__(self, os.path.join(datadir, "gtkbuilder", "main.ui"),
+                            domain="software-properties")
 
     if parent:
       self.window_main.set_type_hint(gtk.gdk.WINDOW_TYPE_HINT_DIALOG)
@@ -142,8 +141,8 @@ class SoftwarePropertiesGtk(SoftwareProperties,SimpleGladeApp):
     #       "sudo software-properties-gtk /etc/apt/sources.list" from the
     #       command line.
     if file != None and \
-       os.path.abspath(file) !=  "%s%s" % (apt_pkg.Config.FindDir("Dir::Etc"),
-                                           apt_pkg.Config.Find("Dir::Etc::sourcelist")):
+       os.path.abspath(file) !=  "%s%s" % (apt_pkg.config.find_dir("Dir::Etc"),
+                                           apt_pkg.config.find("Dir::Etc::sourcelist")):
         self.open_file(file)
 
   def update_interface(self):
@@ -168,6 +167,10 @@ class SoftwarePropertiesGtk(SoftwareProperties,SimpleGladeApp):
 
   def init_auto_update(self):
     """ Set up the widgets that allow to configure the update automation """
+    self.combobox_update_interval = gtk.combo_box_new_text()
+    self.hbox_check_for_updates.pack_start(self.combobox_update_interval)
+    self.combobox_update_interval.show()
+    
     # this maps the key (combo-box-index) to the auto-update-interval value
     # where (-1) means, no key
     self.combobox_interval_mapping = { 0 : 1,
@@ -177,7 +180,6 @@ class SoftwarePropertiesGtk(SoftwareProperties,SimpleGladeApp):
     self.combobox_update_interval.set_active(0)
 
     #update_days = apt_pkg.Config.FindI(softwareproperties.CONF_MAP["autoupdate"])
-
     self.combobox_update_interval.append_text(_("Daily"))
     self.combobox_update_interval.append_text(_("Every two days"))
     self.combobox_update_interval.append_text(_("Weekly"))
@@ -867,20 +869,20 @@ class SoftwarePropertiesGtk(SoftwareProperties,SimpleGladeApp):
     # testing
     #apt_pkg.Config.Set("APT::CDROM::Rename","true")
 
-    saved_entry = apt_pkg.Config.Find("Dir::Etc::sourcelist")
+    saved_entry = apt_pkg.config.find("Dir::Etc::sourcelist")
     tmp = tempfile.NamedTemporaryFile()
-    apt_pkg.Config.Set("Dir::Etc::sourcelist",tmp.name)
+    apt_pkg.config.set("Dir::Etc::sourcelist",tmp.name)
     progress = CdromProgress(self.datadir,self.window_main)
-    cdrom = apt_pkg.GetCdrom()
+    cdrom = apt_pkg.Cdrom()
     # if nothing was found just return
     try:
-      res = cdrom.Add(progress)
+      res = cdrom.add(progress)
     except SystemError, msg:
       error(self.window_main, _("Error scanning the CD"), msg)
       return
     finally:
-      apt_pkg.Config.Set("Dir::Etc::sourcelist",saved_entry)
-      progress.close()
+      apt_pkg.config.set("Dir::Etc::sourcelist",saved_entry)
+      progress.dialog_cdrom_progress.hide()
 
     if res == False:
       return
@@ -889,7 +891,7 @@ class SoftwarePropertiesGtk(SoftwareProperties,SimpleGladeApp):
     for x in open(tmp.name):
       line = x
     if line != "":
-      full_path = "%s%s" % (apt_pkg.Config.FindDir("Dir::Etc"),saved_entry)
+      full_path = "%s%s" % (apt_pkg.config.find_dir("Dir::Etc"),saved_entry)
       # insert cdrom source first, so that it has precedence over network sources
       self.sourceslist.list.insert(0, SourceEntry(line,full_path))
       self.set_modified_sourceslist()
