@@ -711,7 +711,7 @@ class SoftwarePropertiesKDE(SoftwareProperties):
         messageBox.setText(utf8(text))
         messageBox.exec_()
         if (messageBox.clickedButton() == reloadButton):
-                cmd = ["/usr/bin/install-package", "--update"]
+                cmd = ["/usr/bin/qapt-batch", "--update"]
                 subprocess.call(cmd)
     kapp.quit()
 
